#! /bin/sh -e
# tup - A file-based build system
#
# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# Try to 'preload ../..'
. ./tup.sh
check_no_windows run-script

cat > Tupfile << HERE
: |> echo foo > %o |> bar.txt
HERE

mkdir sub
mkdir sub/dir

cat > sub/dir/Tupfile << HERE
preload ../..
run sh -e ok.sh
HERE

cat > sub/dir/ok.sh << HERE
for i in ../../*.txt; do
	echo ": |> echo \$i |>"
done
HERE
update

tup_object_exist sub/dir 'echo ../../bar.txt'

eotup
